@@ -1,4 +1,4 @@
-/* $Header: /CVSROOT/dbm/dbm.c,v 1.21 2007/03/26 16:19:20 tino Exp $
+/* $Header: /CVSROOT/dbm/dbm.c,v 1.22 2007/03/26 18:21:56 tino Exp $
  *
  * A little general DBM wrapper.
  *
@@ -22,6 +22,9 @@
  * USA
  *
  * $Log: dbm.c,v $
+ * Revision 1.22  2007/03/26 18:21:56  tino
+ * Bugfix: db_cmp() had sideffects
+ *
  * Revision 1.21  2007/03/26 16:19:20  tino
  * XML now usable (hopefully).
  * Also major overhaul of some parts.
@@ -391,15 +394,19 @@ static void
 db_cmp(const char *val)
 {
   datum	old;
+  int	oalloc;
 
   old		= data;
+  oalloc	= data_alloc;
   data.dptr	= 0;
   db_get();
   if (!data.dptr)
     ex(1, "key does not exist: %.*s", (int)key.dsize, key.dptr);
   if (data.dsize!=strlen(val) || memcmp(data.dptr,val,data.dsize))
     ex(2, "key data mismatch: %.*s", (int)key.dsize, key.dptr);
+  data_free();
   data		= old;
+  data_alloc	= oalloc;
 }
 
 static void
